@@ -1,7 +1,7 @@
 #!/bin/sh
 
-VERSION="2.6.1"
-VERSION_C="2.6.1"
+VERSION="3.0.2"
+VERSION_C="3.0.0"
 # BUILD_CSFML=FALSE
 BUILD_CSFML=TRUE
 BUILD_SFML=FALSE
@@ -220,11 +220,11 @@ build_sfml () # $1: 'clang' => clang & libc++
 
     case "$2" in
         'frameworks')
-            frameworks="TRUE"
+            frameworks="ON"
             installdir_adapted="$installdir/Library/Frameworks"
             ;;
         'dylibs')
-            frameworks="FALSE"
+            frameworks="OFF"
             installdir_adapted="$installdir/usr/local"
             ;;
         *)
@@ -234,10 +234,10 @@ build_sfml () # $1: 'clang' => clang & libc++
 
     case "$3" in
         'doc')
-            doc="TRUE"
+            doc="ON"
             ;;
         'no doc')
-            doc="FALSE"
+            doc="OFF"
             ;;
         *)
             error "Unknown option for $3 in create_makefile"
@@ -246,12 +246,12 @@ build_sfml () # $1: 'clang' => clang & libc++
 
     case "$4" in
         'examples')
-            examples="TRUE"
+            examples="ON"
             makeopts=""
             # NB: cannot use -j8 here because it bugs with cocoa example...
             ;;
         'no examples')
-            examples="FALSE"
+            examples="OFF"
             makeopts="-j8"
             ;;
         *)
@@ -261,10 +261,10 @@ build_sfml () # $1: 'clang' => clang & libc++
 
     case "$5" in
         'templates')
-            templates="TRUE"
+            templates="ON"
             ;;
         'no templates')
-            templates="FALSE"
+            templates="OFF"
             ;;
         *)
             error "Unknown option for $5 in create_makefile"
@@ -285,7 +285,7 @@ build_sfml () # $1: 'clang' => clang & libc++
     push_pwd "$cmakedir"
 
     cmake -G "Unix Makefiles" \
-          -D "BUILD_SHARED_LIBS:BOOL=TRUE" \
+          -D "BUILD_SHARED_LIBS:BOOL=ON" \
           -D "CMAKE_BUILD_TYPE:STRING=Release" \
           -D "CMAKE_CXX_COMPILER:FILEPATH=/usr/bin/$cxx" \
           -D "CMAKE_CXX_FLAGS:STRING=$cxx_flags" \
@@ -334,10 +334,10 @@ build_csfml () # $1: 'clang' => clang & libc++
 
     case "$2" in
         'doc')
-            doc="TRUE"
+            doc="ON"
             ;;
         'no doc')
-            doc="FALSE"
+            doc="OFF"
             ;;
         *)
             error "Unknown option for $2 in create_makefile"
@@ -360,7 +360,7 @@ build_csfml () # $1: 'clang' => clang & libc++
     push_pwd "$cmakedir"
 
     cmake -G "Unix Makefiles" \
-          -D "BUILD_SHARED_LIBS:BOOL=TRUE" \
+          -D "BUILD_SHARED_LIBS:BOOL=ON" \
           -D "CMAKE_BUILD_TYPE:STRING=Release" \
           -D "CMAKE_CXX_COMPILER:FILEPATH=/usr/bin/$cxx" \
           -D "CMAKE_CXX_FLAGS:STRING=$cxx_flags" \
@@ -371,7 +371,7 @@ build_csfml () # $1: 'clang' => clang & libc++
           -D "CMAKE_OSX_DEPLOYMENT_TARGET:STRING=$target" \
           -D "CMAKE_OSX_SYSROOT:STRING=$sdk" \
           -D "BUILD_DOC:BOOL=$doc" \
-          -D "SFML_DIR:PATH=$sfml_package1070/Frameworks/SFML.framework/Versions/$gittag/Resources/CMake" \
+          -D "SFML_ROOT:PATH=$sfml_package1070/Frameworks/SFML.framework/Versions/$gittag/Resources/CMake" \
           "$codedir"
     assert $? "CMake failed"
 
@@ -492,7 +492,6 @@ create_dir "$sfml_package1070/extlibs/"
 copy "$installdir/Library/Frameworks/FLAC.framework" \
      "$installdir/Library/Frameworks/freetype.framework" \
      "$installdir/Library/Frameworks/ogg.framework" \
-     "$installdir/Library/Frameworks/OpenAL.framework" \
      "$installdir/Library/Frameworks/vorbis.framework" \
      "$installdir/Library/Frameworks/vorbisenc.framework" \
      "$installdir/Library/Frameworks/vorbisfile.framework" \
@@ -574,7 +573,7 @@ minimal_install_package "$sfml_package1070"
 build_csfml 'clang' 'doc' '10.7 SDK'
 
 create_dir "$csfml_package1070/include/"
-copy "$installdir/usr/local/include/SFML" \
+copy "$installdir/usr/local/include/CSFML" \
      "$csfml_package1070/include/"
 
 create_dir "$csfml_package1070/lib/"
@@ -606,4 +605,3 @@ archive "$csfml_package1070" "$csfml_archive1070"
 
 
 ### End Of Script
-
