@@ -34,15 +34,31 @@ set -e
 # =================================================== #
 
 if [[ -z "$1" ]]; then
-    echo "Please specify the platform Runtime Identifier as an argument to this script"
+    echo "Usage: $0 <RID> [<cxx_compiler> <c_compiler>]"
+    echo "Example: $0 linux-arm arm-linux-gnueabihf-g++ arm-linux-gnueabihf-gcc"
     exit 1
 fi
 
 echo "Please note that all SFML dependencies must be installed and available to cmake. SFML does not ship with its linux dependencies."
 
 RID="$1"
+CXX_COMPILER="$2"
+C_COMPILER="$3"
 
-SFMLBranch="2.6.1" # The branch or tag of the SFML repository to be cloned
+if [[ -n "$CXX_COMPILER" || -n "$C_COMPILER" ]]; then
+    if [[ -z "$CXX_COMPILER" || -z "$C_COMPILER" ]]; then
+        echo "When overriding compilers, specify both C++ and C compilers."
+        exit 1
+    fi
+fi
+
+CMAKE_COMPILER_ARGS=()
+if [[ -n "$CXX_COMPILER" ]]; then
+    CMAKE_COMPILER_ARGS+=("-DCMAKE_CXX_COMPILER=$CXX_COMPILER" "-DCMAKE_C_COMPILER=$C_COMPILER")
+    echo "Using custom compilers: CXX=$CXX_COMPILER, CC=$C_COMPILER"
+fi
+
+SFMLBranch="3.0.2" # The branch or tag of the SFML repository to be cloned
 CSFMLDir="$(realpath ../../)"  # The directory of the source code of CSFML
 
 OutDir="./CSFML/runtimes/$RID/native" # The base directory of all CSFML modules, used to copy the final libraries
@@ -87,16 +103,18 @@ mkdir -p lib
 SFMLLibDir="$(realpath lib)"
 
 cmake -E env LDFLAGS="-z origin" \
-    cmake \
-    '-DBUILD_SHARED_LIBS=1' \
+    cmake "${CMAKE_COMPILER_ARGS[@]}" \
+    '-DBUILD_SHARED_LIBS=ON' \
     '-DCMAKE_BUILD_TYPE=Release' \
+    "-DCMAKE_INSTALL_PREFIX=$SFMLLibDir" \
     "-DCMAKE_LIBRARY_OUTPUT_DIRECTORY=$SFMLLibDir" \
-    '-DCMAKE_BUILD_WITH_INSTALL_RPATH=1' \
+    '-DCMAKE_BUILD_WITH_INSTALL_RPATH=ON' \
     '-DCMAKE_INSTALL_RPATH=$ORIGIN' \
-    '-DSFML_BUILD_NETWORK=0' \
+    '-DSFML_USE_SYSTEM_DEPS=OFF' \
+    '-DSFML_BUILD_NETWORK=OFF' \
     "$SFMLDir"
 
-cmake --build . --config Release
+cmake --build . --config Release --target install
 
 popd # Pop SFML
 
@@ -112,14 +130,14 @@ mkdir -p lib
 CSFMLLibDir="$(realpath lib)" # The directory that contains the final CSFML libraries. Used to copy the result into SFML.Net
 
 cmake -E env LDFLAGS="-z origin" \
-    cmake \
-    "-DSFML_DIR=$SFMLBuiltDir" \
-    '-DBUILD_SHARED_LIBS=1' \
+    cmake "${CMAKE_COMPILER_ARGS[@]}" \
+    "-DSFML_ROOT=$SFMLLibDir" \
+    '-DBUILD_SHARED_LIBS=ON' \
     '-DCMAKE_BUILD_TYPE=Release' \
     "-DCMAKE_LIBRARY_OUTPUT_DIRECTORY=$CSFMLLibDir" \
-    '-DCMAKE_BUILD_WITH_INSTALL_RPATH=1' \
+    '-DCMAKE_BUILD_WITH_INSTALL_RPATH=ON' \
     '-DCMAKE_INSTALL_RPATH=$ORIGIN' \
-    '-DCSFML_BUILD_NETWORK=0' \
+    '-DCSFML_BUILD_NETWORK=OFF' \
     "$CSFMLDir"
 cmake --build . --config Release
 
@@ -127,8 +145,8 @@ cmake --build . --config Release
 # STEP 5: Copy result to the NuGet folders #
 # ======================================== #
 
-SFMLMajorMinor="2.6"
-CSFMLMajorMinor="2.6"
+SFMLMajorMinor="3.0"
+CSFMLMajorMinor="3.0"
 
 # Copies one SFML and CSFML module into the NuGet package
 # The module name must be passed to this function as an argument, in lowercase
@@ -143,7 +161,7 @@ copymodule()
     # SFML.Net only searches for the name with common pre- and suffixes
     # As such we need to ship e.g. libcsfml-graphics.so
     # But the CSFML libs will look for the major.minor version
-    # As such we also need to ship e.g. libcsfml-graphics.so.2.6
+    # As such we also need to ship e.g. libcsfml-graphics.so.3.0
     # Unfortunately NuGet package don't support symlinks: https://github.com/NuGet/Home/issues/10734
     # For SFML, we can just ship one version that CSFML will be looking for
     cp "$SFMLLibDir/libsfml-$MODULE.so.$SFMLMajorMinor" "$OutDir"
